ScoreAlignment class

Represents a score alignment for partial ratio calculations

Constructors

ScoreAlignment({double score = 0.0, int srcStart = 0, int srcEnd = 0, int destStart = 0, int destEnd = 0})

Properties

destEnd → int
final
destStart → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double
final
srcEnd → int
final
srcStart → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited