ExtractedResult<T> class

A model class representing results extracted from a list

Implemented types

Constructors

ExtractedResult(T choice, double score, int index, String _getter(T obj))
Creates a new ExtractedResult with the given choice, score and index

Properties

choice → T
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double
final

Methods

compareTo(ExtractedResult other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited